pub enum PaintServer {
None,
Iri {
iri: Box<NodeId>,
alternate: Option<Color>,
},
SolidColor(Color),
ContextFill,
ContextStroke,
}Expand description
Unresolved SVG paint server straight from the DOM data.
This is either a solid color (which if currentColor needs to be extracted from the
ComputedValues), or a paint server like a gradient or pattern which is referenced by
a URL that points to a certain document node.
Use PaintServer.resolve to turn this into a PaintSource.
Variants
None
For example, fill="none".
Iri
For example, fill="url(#some_gradient) fallback_color".
SolidColor(Color)
For example, fill="blue".
ContextFill
For example, fill="context-fill"
ContextStroke
For example, fill="context-stroke"
Implementations
Sourceimpl PaintServer
impl PaintServer
Sourcepub fn resolve(
&self,
acquired_nodes: &mut AcquiredNodes<'_>,
referencing_element_name: &str,
opacity: UnitInterval,
current_color: Color,
context_fill: Option<Rc<PaintSource>>,
context_stroke: Option<Rc<PaintSource>>,
session: &Session,
) -> Rc<PaintSource>
pub fn resolve( &self, acquired_nodes: &mut AcquiredNodes<'_>, referencing_element_name: &str, opacity: UnitInterval, current_color: Color, context_fill: Option<Rc<PaintSource>>, context_stroke: Option<Rc<PaintSource>>, session: &Session, ) -> Rc<PaintSource>
Resolves colors, plus node references for gradients and patterns.
opacity depends on strokeOpacity or fillOpacity depending on whether
the paint server is for the stroke or fill properties.
current_color should be the value of ComputedValues.color().
After a paint server is resolved, the resulting PaintSource can be used in
many places: for an actual shape, or for the context-fill of a marker for that
shape. Therefore, this returns an Rc so that the PaintSource may be shared
easily.